@@ -1,6 +1,7 @@
 from sqlglot.optimizer.normalize import normalize
 from sqlglot.optimizer.decorrelate_subqueries import decorrelate_subqueries
 from sqlglot.optimizer.eliminate_subqueries import eliminate_subqueries
+from sqlglot.optimizer.isolate_table_selects import isolate_table_selects
 from sqlglot.optimizer.expand_multi_table_selects import expand_multi_table_selects
 from sqlglot.optimizer.optimize_joins import optimize_joins
 from sqlglot.optimizer.pushdown_predicates import pushdown_predicates
@@ -8,7 +9,6 @@ from sqlglot.optimizer.pushdown_projections import pushdown_projections
 from sqlglot.optimizer.qualify_tables import qualify_tables
 from sqlglot.optimizer.qualify_columns import qualify_columns
 from sqlglot.optimizer.quote_identities import quote_identities
-from sqlglot.optimizer.simplify import simplify
 
 
 def optimize(expression, schema=None, db=None, catalog=None):
@@ -30,6 +30,7 @@ def optimize(expression, schema=None, db=None, catalog=None):
     """
     expression = expression.copy()
     expression = qualify_tables(expression, db=db, catalog=catalog)
+    expression = isolate_table_selects(expression)
     expression = qualify_columns(expression, schema)
     expression = pushdown_projections(expression)
     expression = normalize(expression)
@@ -37,7 +38,6 @@ def optimize(expression, schema=None, db=None, catalog=None):
     expression = expand_multi_table_selects(expression)
     expression = pushdown_predicates(expression)
     expression = optimize_joins(expression)
-    expression = simplify(expression)
     expression = eliminate_subqueries(expression)
     expression = quote_identities(expression)
     return expression
